@@ -11,7 +11,7 @@ pub mod wire_msg_header;
 
 use self::wire_msg_header::{MessageKind, WireMsgHeader};
 #[cfg(not(feature = "client-only"))]
-use super::node;
+use super::node::{self, Variant};
 use super::{client, section_info, DestInfo, Error, MessageId, MessageType, Result};
 use bytes::Bytes;
 use cookie_factory::{combinator::slice, gen_simple};
@@ -132,6 +132,23 @@ impl WireMsg {
         Ok(Self { header, payload })
     }
 
+    #[cfg(not(feature = "client-only"))]
+    pub fn is_join_request(&self) -> Result<bool> {
+        if let MessageKind::Routing = self.header.kind() {
+            if let MessageType::Routing { msg, .. } = self.to_message()? {
+                if let Variant::JoinRequest(_) = msg.variant {
+                    Ok(true)
+                } else {
+                    Ok(false)
+                }
+            } else {
+                Ok(false)
+            }
+        } else {
+            Ok(false)
+        }
+    }
+
     /// Return the serialized WireMsg, which contains the WireMsgHeader bytes,
     /// followed by the payload bytes, i.e. the serialized Message.
     pub fn serialize(&self) -> Result<Bytes> {
